/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: cmi@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id: ILoadBalancingService.java 2317 2009-05-11 09:17:33Z eyindanga $
 * --------------------------------------------------------------------------
 */
package org.ow2.cmi.osgi;

import java.net.URL;

import org.ow2.cmi.lb.policy.IPolicy;
import org.ow2.cmi.lb.strategy.IStrategy;

/**
 * Interface for Load Balancing service exported by OSGI bundles that embed
 * Strategies and/or Policies.
 * @author The new CMI team
 *
 */
public interface ILoadBalancingService {
    /**
     * Gets the URL of the bundle thats started the service.
     * @return The url of the archive.
     */
    URL getArchiveUrl();

    /**
     * @return strategies exported by the service
     */
    Class<? extends IStrategy<?>>[] getStrategies();

    /**
     * @return Policies exported by the service
     */
    Class<? extends IPolicy<?>>[] getPolicies();
    /**
     * Starts the service.
     */
    void start();

    /**
     * Stops the service.
     */
    void stop();


}
